@@ -7,7 +7,7 @@ package BSON::PP;
 # ABSTRACT: Pure Perl BSON implementation
 
 use version;
-our $VERSION = 'v1.10.0';
+our $VERSION = 'v1.10.1';
 
 use B;
 use Carp;
@@ -194,10 +194,17 @@ sub _encode_bson {
 
     my $doc_type = ref($doc);
 
-    return $doc->bson
-      if $doc_type eq 'BSON::Raw' || $doc_type eq 'MongoDB::BSON::_EncodedDoc';
+    if ( $doc_type eq 'BSON::Raw' || $doc_type eq 'MongoDB::BSON::_EncodedDoc' ) {
+        delete $opt->{_circular}{$refaddr};
+        $opt->{_depth}--;
+        return $doc->bson;
+    }
 
-    return $$doc if $doc_type eq 'MongoDB::BSON::Raw';
+    if ( $doc_type eq 'MongoDB::BSON::Raw' ) {
+        delete $opt->{_circular}{$refaddr};
+        $opt->{_depth}--;
+        return $$doc;
+    }
 
     my $iter =
         $doc_type eq 'HASH'           ? undef
@@ -846,7 +853,7 @@ BSON::PP - Pure Perl BSON implementation
 
 =head1 VERSION
 
-version v1.10.0
+version v1.10.1
 
 =head1 DESCRIPTION
 
